==> jc-1.4.0.tar.gz: soot/xml/LinkAttribute.h <==
// public class soot.xml.LinkAttribute

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8516d9b18d5ab862 soot_xml_LinkAttribute

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_xml_LinkAttribute_H_
#define _JC_soot_xml_LinkAttribute_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_xml_LinkAttribute$sub_refs	_jc_soot_xml_LinkAttribute$sub_refs;
typedef struct _jc_soot_xml_LinkAttribute$sub_nonrefs	_jc_soot_xml_LinkAttribute$sub_nonrefs;
typedef struct _jc_soot_xml_LinkAttribute$refs	_jc_soot_xml_LinkAttribute$refs;
typedef struct _jc_soot_xml_LinkAttribute$nonrefs	_jc_soot_xml_LinkAttribute$nonrefs;
typedef struct _jc_soot_xml_LinkAttribute$object	_jc_soot_xml_LinkAttribute$object;

typedef const struct _jc_soot_xml_LinkAttribute$vmethods	_jc_soot_xml_LinkAttribute$vmethods;
typedef const struct _jc_soot_xml_LinkAttribute$vtable	_jc_soot_xml_LinkAttribute$vtable;
typedef const struct _jc_soot_xml_LinkAttribute$vtype	_jc_soot_xml_LinkAttribute$vtype;

// Constructors
extern void _jc_soot_xml_LinkAttribute$method$_init$03e7628dad980424(_jc_env *, struct _jc_soot_xml_LinkAttribute$object *, struct _jc_java_lang_String$object *, jint, jint, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_xml_LinkAttribute$method$className$068a14fdb0af01b9(_jc_env *, struct _jc_soot_xml_LinkAttribute$object *);
extern struct _jc_java_lang_String$object *_jc_soot_xml_LinkAttribute$method$info$2f20b4750585496d(_jc_env *, struct _jc_soot_xml_LinkAttribute$object *);
extern jboolean _jc_soot_xml_LinkAttribute$method$isJavaLink$6fba1f25cc6212c7(_jc_env *, struct _jc_soot_xml_LinkAttribute$object *);
extern jboolean _jc_soot_xml_LinkAttribute$method$isJimpleLink$ac0a2d3f361f4723(_jc_env *, struct _jc_soot_xml_LinkAttribute$object *);
extern jint _jc_soot_xml_LinkAttribute$method$javaLink$6314488d02ff736e(_jc_env *, struct _jc_soot_xml_LinkAttribute$object *);
extern jint _jc_soot_xml_LinkAttribute$method$jimpleLink$1621448905f75a54(_jc_env *, struct _jc_soot_xml_LinkAttribute$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_xml_LinkAttribute$method_info$className$068a14fdb0af01b9;
extern _jc_method _jc_soot_xml_LinkAttribute$method_info$info$2f20b4750585496d;
extern _jc_method _jc_soot_xml_LinkAttribute$method_info$isJavaLink$6fba1f25cc6212c7;
extern _jc_method _jc_soot_xml_LinkAttribute$method_info$isJimpleLink$ac0a2d3f361f4723;
extern _jc_method _jc_soot_xml_LinkAttribute$method_info$javaLink$6314488d02ff736e;
extern _jc_method _jc_soot_xml_LinkAttribute$method_info$jimpleLink$1621448905f75a54;

// Virtual methods structure
struct _jc_soot_xml_LinkAttribute$vmethods {
	struct _jc_java_lang_String$object	*(*className$068a14fdb0af01b9)(_jc_env *, struct _jc_soot_xml_LinkAttribute$object *);
	struct _jc_java_lang_String$object	*(*info$2f20b4750585496d)(_jc_env *, struct _jc_soot_xml_LinkAttribute$object *);
	jboolean	(*isJavaLink$6fba1f25cc6212c7)(_jc_env *, struct _jc_soot_xml_LinkAttribute$object *);
	jboolean	(*isJimpleLink$ac0a2d3f361f4723)(_jc_env *, struct _jc_soot_xml_LinkAttribute$object *);
	jint	(*javaLink$6314488d02ff736e)(_jc_env *, struct _jc_soot_xml_LinkAttribute$object *);
	jint	(*jimpleLink$1621448905f75a54)(_jc_env *, struct _jc_soot_xml_LinkAttribute$object *);
};

// Vtable
struct _jc_soot_xml_LinkAttribute$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_xml_LinkAttribute$vmethods	soot_xml_LinkAttribute;
};

// Vtype
struct _jc_soot_xml_LinkAttribute$vtype {
	_jc_type			type;
	_jc_soot_xml_LinkAttribute$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_xml_LinkAttribute$sub_refs {
	struct _jc_java_lang_String$object	*info;
	struct _jc_java_lang_String$object	*className;
};

// Reference instance fields (object)
struct _jc_soot_xml_LinkAttribute$refs {
    _jc_soot_xml_LinkAttribute$sub_refs	soot_xml_LinkAttribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_xml_LinkAttribute$sub_nonrefs {
	jint	jimpleLink;
	jint	javaLink;
	jboolean	isJimpleLink;
	jboolean	isJavaLink;
};

// Non-reference instance fields (object)
struct _jc_soot_xml_LinkAttribute$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_xml_LinkAttribute$sub_nonrefs	soot_xml_LinkAttribute;
};

// Object instance structure
struct _jc_soot_xml_LinkAttribute$object {
	_jc_soot_xml_LinkAttribute$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_xml_LinkAttribute$vtype	*vtype;
	_jc_soot_xml_LinkAttribute$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_xml_LinkAttribute$vtype _jc_soot_xml_LinkAttribute$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_xml_LinkAttribute, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_xml_LinkAttribute$class_object;

#endif	/* _JC_soot_xml_LinkAttribute_H_ */

==> jc-1.4.6.tar.gz: soot/xml/LinkAttribute.h <==
// public class soot.xml.LinkAttribute

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8516d9b18d5ab862 soot_xml_LinkAttribute

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_xml_LinkAttribute_H_
#define _JC_soot_xml_LinkAttribute_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_xml_LinkAttribute$sub_refs	_jc_soot_xml_LinkAttribute$sub_refs;
typedef struct _jc_soot_xml_LinkAttribute$sub_nonrefs	_jc_soot_xml_LinkAttribute$sub_nonrefs;
typedef struct _jc_soot_xml_LinkAttribute$refs	_jc_soot_xml_LinkAttribute$refs;
typedef struct _jc_soot_xml_LinkAttribute$nonrefs	_jc_soot_xml_LinkAttribute$nonrefs;
typedef struct _jc_soot_xml_LinkAttribute$object	_jc_soot_xml_LinkAttribute$object;

typedef const struct _jc_soot_xml_LinkAttribute$vmethods	_jc_soot_xml_LinkAttribute$vmethods;
typedef const struct _jc_soot_xml_LinkAttribute$vtable	_jc_soot_xml_LinkAttribute$vtable;
typedef const struct _jc_soot_xml_LinkAttribute$vtype	_jc_soot_xml_LinkAttribute$vtype;

// Constructors
extern void _jc_soot_xml_LinkAttribute$method$_init$03e7628dad980424(_jc_env *, struct _jc_soot_xml_LinkAttribute$object *, struct _jc_java_lang_String$object *, jint, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_xml_LinkAttribute$method$className$068a14fdb0af01b9(_jc_env *, struct _jc_soot_xml_LinkAttribute$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_xml_LinkAttribute$method$info$2f20b4750585496d(_jc_env *, struct _jc_soot_xml_LinkAttribute$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_xml_LinkAttribute$method$isJavaLink$6fba1f25cc6212c7(_jc_env *, struct _jc_soot_xml_LinkAttribute$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_xml_LinkAttribute$method$isJimpleLink$ac0a2d3f361f4723(_jc_env *, struct _jc_soot_xml_LinkAttribute$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_xml_LinkAttribute$method$javaLink$6314488d02ff736e(_jc_env *, struct _jc_soot_xml_LinkAttribute$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_xml_LinkAttribute$method$jimpleLink$1621448905f75a54(_jc_env *, struct _jc_soot_xml_LinkAttribute$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_xml_LinkAttribute$method_info$className$068a14fdb0af01b9;
extern _jc_method _jc_soot_xml_LinkAttribute$method_info$info$2f20b4750585496d;
extern _jc_method _jc_soot_xml_LinkAttribute$method_info$isJavaLink$6fba1f25cc6212c7;
extern _jc_method _jc_soot_xml_LinkAttribute$method_info$isJimpleLink$ac0a2d3f361f4723;
extern _jc_method _jc_soot_xml_LinkAttribute$method_info$javaLink$6314488d02ff736e;
extern _jc_method _jc_soot_xml_LinkAttribute$method_info$jimpleLink$1621448905f75a54;

// Virtual methods structure
struct _jc_soot_xml_LinkAttribute$vmethods {
	struct _jc_java_lang_String$object	*(*className$068a14fdb0af01b9)(_jc_env *, struct _jc_soot_xml_LinkAttribute$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*info$2f20b4750585496d)(_jc_env *, struct _jc_soot_xml_LinkAttribute$object *) _JC_JCNI_ATTR;
	jboolean	(*isJavaLink$6fba1f25cc6212c7)(_jc_env *, struct _jc_soot_xml_LinkAttribute$object *) _JC_JCNI_ATTR;
	jboolean	(*isJimpleLink$ac0a2d3f361f4723)(_jc_env *, struct _jc_soot_xml_LinkAttribute$object *) _JC_JCNI_ATTR;
	jint	(*javaLink$6314488d02ff736e)(_jc_env *, struct _jc_soot_xml_LinkAttribute$object *) _JC_JCNI_ATTR;
	jint	(*jimpleLink$1621448905f75a54)(_jc_env *, struct _jc_soot_xml_LinkAttribute$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_xml_LinkAttribute$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_xml_LinkAttribute$vmethods	soot_xml_LinkAttribute;
};

// Vtype
struct _jc_soot_xml_LinkAttribute$vtype {
	_jc_type			type;
	_jc_soot_xml_LinkAttribute$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_xml_LinkAttribute$sub_refs {
	struct _jc_java_lang_String$object	*info;
	struct _jc_java_lang_String$object	*className;
};

// Reference instance fields (object)
struct _jc_soot_xml_LinkAttribute$refs {
    _jc_soot_xml_LinkAttribute$sub_refs	soot_xml_LinkAttribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_xml_LinkAttribute$sub_nonrefs {
	jint	jimpleLink;
	jint	javaLink;
	jboolean	isJimpleLink;
	jboolean	isJavaLink;
};

// Non-reference instance fields (object)
struct _jc_soot_xml_LinkAttribute$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_xml_LinkAttribute$sub_nonrefs	soot_xml_LinkAttribute;
};

// Object instance structure
struct _jc_soot_xml_LinkAttribute$object {
	_jc_soot_xml_LinkAttribute$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_xml_LinkAttribute$vtype	*vtype;
	_jc_soot_xml_LinkAttribute$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_xml_LinkAttribute$vtype _jc_soot_xml_LinkAttribute$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_xml_LinkAttribute, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_xml_LinkAttribute$class_object;

#endif	/* _JC_soot_xml_LinkAttribute_H_ */
